/*
 * convertercontrol.h
 * Copyright 2012, Stefan Beller, stefanbeller@googlemail.com
 *
 * This file is part of the AutomappingConverter, which converts old rulemaps
 * of Tiled to work with the latest version of Tiled.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <QString>
#include <QObject>

class ConverterControl
{
public:
    ConverterControl();

    QString version1() const { return QObject::tr("v0.8 and before"); }
    QString version2() const { return QObject::tr("v0.9 and later"); }
    QString versionUnknown() const { return QObject::tr("unknown"); }
    QString versionNotAMap() const { return QObject::tr("not a map"); }

    QString automappingRuleFileVersion(const QString &fileName);
    void convertV1toV2(const QString &fileName);
};
